# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from featureflags_protobuf import service_pb2 as featureflags__protobuf_dot_service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FeatureFlagsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.exchange = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/exchange',
                request_serializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
                response_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
                )
        self.Exchange = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/Exchange',
                request_serializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
                response_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
                )
        self.store_stats = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/store_stats',
                request_serializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StoreStats = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/StoreStats',
                request_serializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class FeatureFlagsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def exchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def store_stats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StoreStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureFlagsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'exchange': grpc.unary_unary_rpc_method_handler(
                    servicer.exchange,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.FromString,
                    response_serializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.SerializeToString,
            ),
            'Exchange': grpc.unary_unary_rpc_method_handler(
                    servicer.Exchange,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.FromString,
                    response_serializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.SerializeToString,
            ),
            'store_stats': grpc.unary_unary_rpc_method_handler(
                    servicer.store_stats,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StoreStats': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreStats,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'featureflags_protobuf.service.FeatureFlags', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureFlags(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def exchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/exchange',
            featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
            featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Exchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/Exchange',
            featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
            featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def store_stats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/store_stats',
            featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StoreStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/StoreStats',
            featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags_protobuf/backend.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags_protobuf import graph_pb2 as featureflags__protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#featureflags_protobuf/backend.proto\x12\x1d\x66\x65\x61tureflags_protobuf.backend\x1a\x19hiku/protobuf/query.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags_protobuf/graph.proto\"\x13\n\x02Id\x12\r\n\x05value\x18\x01 \x01(\t\"\'\n\x07LocalId\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\"\x7f\n\x08\x45itherId\x12/\n\x02id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.IdH\x00\x12:\n\x08local_id\x18\x02 \x01(\x0b\x32&.featureflags_protobuf.backend.LocalIdH\x00\x42\x06\n\x04kind\",\n\x06SignIn\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\t\n\x07SignOut\"@\n\nEnableFlag\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"A\n\x0b\x44isableFlag\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"?\n\tResetFlag\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"\xde\x02\n\x08\x41\x64\x64\x43heck\x12\x38\n\x08local_id\x18\x01 \x01(\x0b\x32&.featureflags_protobuf.backend.LocalId\x12\x33\n\x08variable\x18\x02 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\x12=\n\x08operator\x18\x03 \x01(\x0e\x32+.featureflags_protobuf.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x35\n\tvalue_set\x18\x07 \x01(\x0b\x32 .featureflags_protobuf.graph.SetH\x00\x42\x06\n\x04kind\"\xb5\x01\n\x0c\x41\x64\x64\x43ondition\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\x12\x38\n\x08local_id\x18\x02 \x01(\x0b\x32&.featureflags_protobuf.backend.LocalId\x12\x37\n\x06\x63hecks\x18\x03 \x03(\x0b\x32\'.featureflags_protobuf.backend.EitherId\"K\n\x10\x44isableCondition\x12\x37\n\x0c\x63ondition_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"\x9f\x04\n\tOperation\x12@\n\x0b\x65nable_flag\x18\x01 \x01(\x0b\x32).featureflags_protobuf.backend.EnableFlagH\x00\x12\x42\n\x0c\x64isable_flag\x18\x02 \x01(\x0b\x32*.featureflags_protobuf.backend.DisableFlagH\x00\x12\x44\n\radd_condition\x18\x03 \x01(\x0b\x32+.featureflags_protobuf.backend.AddConditionH\x00\x12L\n\x11\x64isable_condition\x18\x04 \x01(\x0b\x32/.featureflags_protobuf.backend.DisableConditionH\x00\x12<\n\tadd_check\x18\x05 \x01(\x0b\x32\'.featureflags_protobuf.backend.AddCheckH\x00\x12>\n\nreset_flag\x18\x06 \x01(\x0b\x32(.featureflags_protobuf.backend.ResetFlagH\x00\x12\x38\n\x07sign_in\x18\x07 \x01(\x0b\x32%.featureflags_protobuf.backend.SignInH\x00\x12:\n\x08sign_out\x18\x08 \x01(\x0b\x32&.featureflags_protobuf.backend.SignOutH\x00\x42\x04\n\x02op\"q\n\x07Request\x12<\n\noperations\x18\x01 \x03(\x0b\x32(.featureflags_protobuf.backend.Operation\x12(\n\x05query\x18\x02 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"<\n\x05Reply\x12\x33\n\x06result\x18\x01 \x01(\x0b\x32#.featureflags_protobuf.graph.Result2\xbc\x01\n\x07\x42\x61\x63kend\x12Y\n\x04\x63\x61ll\x12&.featureflags_protobuf.backend.Request\x1a$.featureflags_protobuf.backend.Reply\"\x03\x88\x02\x01\x12V\n\x04\x43\x61ll\x12&.featureflags_protobuf.backend.Request\x1a$.featureflags_protobuf.backend.Reply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureflags_protobuf.backend_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BACKEND'].methods_by_name['call']._options = None
  _globals['_BACKEND'].methods_by_name['call']._serialized_options = b'\210\002\001'
  _globals['_ID']._serialized_start=165
  _globals['_ID']._serialized_end=184
  _globals['_LOCALID']._serialized_start=186
  _globals['_LOCALID']._serialized_end=225
  _globals['_EITHERID']._serialized_start=227
  _globals['_EITHERID']._serialized_end=354
  _globals['_SIGNIN']._serialized_start=356
  _globals['_SIGNIN']._serialized_end=400
  _globals['_SIGNOUT']._serialized_start=402
  _globals['_SIGNOUT']._serialized_end=411
  _globals['_ENABLEFLAG']._serialized_start=413
  _globals['_ENABLEFLAG']._serialized_end=477
  _globals['_DISABLEFLAG']._serialized_start=479
  _globals['_DISABLEFLAG']._serialized_end=544
  _globals['_RESETFLAG']._serialized_start=546
  _globals['_RESETFLAG']._serialized_end=609
  _globals['_ADDCHECK']._serialized_start=612
  _globals['_ADDCHECK']._serialized_end=962
  _globals['_ADDCONDITION']._serialized_start=965
  _globals['_ADDCONDITION']._serialized_end=1146
  _globals['_DISABLECONDITION']._serialized_start=1148
  _globals['_DISABLECONDITION']._serialized_end=1223
  _globals['_OPERATION']._serialized_start=1226
  _globals['_OPERATION']._serialized_end=1769
  _globals['_REQUEST']._serialized_start=1771
  _globals['_REQUEST']._serialized_end=1884
  _globals['_REPLY']._serialized_start=1886
  _globals['_REPLY']._serialized_end=1946
  _globals['_BACKEND']._serialized_start=1949
  _globals['_BACKEND']._serialized_end=2137
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags_protobuf/graph.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!featureflags_protobuf/graph.proto\x12\x1b\x66\x65\x61tureflags_protobuf.graph\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"h\n\x03Ref\x12\x11\n\x07Project\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x46lag\x18\x02 \x01(\tH\x00\x12\x13\n\tCondition\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x43heck\x18\x04 \x01(\tH\x00\x12\x12\n\x08Variable\x18\x05 \x01(\tH\x00\x42\x04\n\x02to\"\x14\n\x03Set\x12\r\n\x05items\x18\x01 \x03(\t\"\xa7\x01\n\x08Variable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x38\n\x04type\x18\x03 \x01(\x0e\x32*.featureflags_protobuf.graph.Variable.Type\"G\n\x04Type\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\x07\n\x03SET\x10\x04\"\xee\x03\n\x05\x43heck\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x08variable\x18\x02 \x01(\x0b\x32 .featureflags_protobuf.graph.Ref\x12=\n\x08operator\x18\x03 \x01(\x0e\x32+.featureflags_protobuf.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x35\n\tvalue_set\x18\x07 \x01(\x0b\x32 .featureflags_protobuf.graph.SetH\x00\"\xbf\x01\n\x08Operator\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tLESS_THAN\x10\x02\x12\x11\n\rLESS_OR_EQUAL\x10\x03\x12\x10\n\x0cGREATER_THAN\x10\x04\x12\x14\n\x10GREATER_OR_EQUAL\x10\x05\x12\x0c\n\x08\x43ONTAINS\x10\x06\x12\x0b\n\x07PERCENT\x10\x07\x12\n\n\x06REGEXP\x10\x08\x12\x0c\n\x08WILDCARD\x10\t\x12\n\n\x06SUBSET\x10\n\x12\x0c\n\x08SUPERSET\x10\x0b\x42\x06\n\x04kind\"I\n\tCondition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x06\x63hecks\x18\x02 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\"\xe6\x01\n\x04\x46lag\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n\x07project\x18\x03 \x01(\x0b\x32 .featureflags_protobuf.graph.Ref\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\nconditions\x18\x05 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\x12.\n\noverridden\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"i\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\r\x12\x33\n\tvariables\x18\x03 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\"\xea\x01\n\x04Root\x12.\n\x04\x66lag\x18\x01 \x01(\x0b\x32 .featureflags_protobuf.graph.Ref\x12/\n\x05\x66lags\x18\x02 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\x12\x32\n\x08projects\x18\x03 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\x12\x15\n\rauthenticated\x18\x05 \x01(\x08\x12\x36\n\x0c\x66lags_by_ids\x18\x06 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\"\xae\x06\n\x06Result\x12/\n\x04Root\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.graph.Root\x12\x41\n\x07Project\x18\x02 \x03(\x0b\x32\x30.featureflags_protobuf.graph.Result.ProjectEntry\x12;\n\x04\x46lag\x18\x03 \x03(\x0b\x32-.featureflags_protobuf.graph.Result.FlagEntry\x12\x45\n\tCondition\x18\x04 \x03(\x0b\x32\x32.featureflags_protobuf.graph.Result.ConditionEntry\x12=\n\x05\x43heck\x18\x05 \x03(\x0b\x32..featureflags_protobuf.graph.Result.CheckEntry\x12\x43\n\x08Variable\x18\x06 \x03(\x0b\x32\x31.featureflags_protobuf.graph.Result.VariableEntry\x1aT\n\x0cProjectEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.featureflags_protobuf.graph.Project:\x02\x38\x01\x1aN\n\tFlagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.featureflags_protobuf.graph.Flag:\x02\x38\x01\x1aX\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.featureflags_protobuf.graph.Condition:\x02\x38\x01\x1aP\n\nCheckEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".featureflags_protobuf.graph.Check:\x02\x38\x01\x1aV\n\rVariableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.featureflags_protobuf.graph.Variable:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureflags_protobuf.graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RESULT_PROJECTENTRY']._options = None
  _globals['_RESULT_PROJECTENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_FLAGENTRY']._options = None
  _globals['_RESULT_FLAGENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_CONDITIONENTRY']._options = None
  _globals['_RESULT_CONDITIONENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_CHECKENTRY']._options = None
  _globals['_RESULT_CHECKENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_VARIABLEENTRY']._options = None
  _globals['_RESULT_VARIABLEENTRY']._serialized_options = b'8\001'
  _globals['_REF']._serialized_start=131
  _globals['_REF']._serialized_end=235
  _globals['_SET']._serialized_start=237
  _globals['_SET']._serialized_end=257
  _globals['_VARIABLE']._serialized_start=260
  _globals['_VARIABLE']._serialized_end=427
  _globals['_VARIABLE_TYPE']._serialized_start=356
  _globals['_VARIABLE_TYPE']._serialized_end=427
  _globals['_CHECK']._serialized_start=430
  _globals['_CHECK']._serialized_end=924
  _globals['_CHECK_OPERATOR']._serialized_start=725
  _globals['_CHECK_OPERATOR']._serialized_end=916
  _globals['_CONDITION']._serialized_start=926
  _globals['_CONDITION']._serialized_end=999
  _globals['_FLAG']._serialized_start=1002
  _globals['_FLAG']._serialized_end=1232
  _globals['_PROJECT']._serialized_start=1234
  _globals['_PROJECT']._serialized_end=1339
  _globals['_ROOT']._serialized_start=1342
  _globals['_ROOT']._serialized_end=1576
  _globals['_RESULT']._serialized_start=1579
  _globals['_RESULT']._serialized_end=2393
  _globals['_RESULT_PROJECTENTRY']._serialized_start=1969
  _globals['_RESULT_PROJECTENTRY']._serialized_end=2053
  _globals['_RESULT_FLAGENTRY']._serialized_start=2055
  _globals['_RESULT_FLAGENTRY']._serialized_end=2133
  _globals['_RESULT_CONDITIONENTRY']._serialized_start=2135
  _globals['_RESULT_CONDITIONENTRY']._serialized_end=2223
  _globals['_RESULT_CHECKENTRY']._serialized_start=2225
  _globals['_RESULT_CHECKENTRY']._serialized_end=2305
  _globals['_RESULT_VARIABLEENTRY']._serialized_start=2307
  _globals['_RESULT_VARIABLEENTRY']._serialized_end=2393
# @@protoc_insertion_point(module_scope)



# Generated by the Protocol Buffers compiler. DO NOT EDIT!
# source: featureflags_protobuf/service.proto
# plugin: grpclib.plugin.main
import abc
import typing

import grpclib.const
import grpclib.client
if typing.TYPE_CHECKING:
    import grpclib.server

import hiku.protobuf.query_pb2
import google.protobuf.empty_pb2
import google.protobuf.timestamp_pb2
import featureflags_protobuf.graph_pb2
import featureflags_protobuf.service_pb2


class FeatureFlagsBase(abc.ABC):

    @abc.abstractmethod
    async def exchange(self, stream: 'grpclib.server.Stream[featureflags_protobuf.service_pb2.ExchangeRequest, featureflags_protobuf.service_pb2.ExchangeReply]') -> None:
        pass

    @abc.abstractmethod
    async def Exchange(self, stream: 'grpclib.server.Stream[featureflags_protobuf.service_pb2.ExchangeRequest, featureflags_protobuf.service_pb2.ExchangeReply]') -> None:
        pass

    @abc.abstractmethod
    async def store_stats(self, stream: 'grpclib.server.Stream[featureflags_protobuf.service_pb2.StoreStatsTask, google.protobuf.empty_pb2.Empty]') -> None:
        pass

    @abc.abstractmethod
    async def StoreStats(self, stream: 'grpclib.server.Stream[featureflags_protobuf.service_pb2.StoreStatsTask, google.protobuf.empty_pb2.Empty]') -> None:
        pass

    def __mapping__(self) -> typing.Dict[str, grpclib.const.Handler]:
        return {
            '/featureflags_protobuf.service.FeatureFlags/exchange': grpclib.const.Handler(
                self.exchange,
                grpclib.const.Cardinality.UNARY_UNARY,
                featureflags_protobuf.service_pb2.ExchangeRequest,
                featureflags_protobuf.service_pb2.ExchangeReply,
            ),
            '/featureflags_protobuf.service.FeatureFlags/Exchange': grpclib.const.Handler(
                self.Exchange,
                grpclib.const.Cardinality.UNARY_UNARY,
                featureflags_protobuf.service_pb2.ExchangeRequest,
                featureflags_protobuf.service_pb2.ExchangeReply,
            ),
            '/featureflags_protobuf.service.FeatureFlags/store_stats': grpclib.const.Handler(
                self.store_stats,
                grpclib.const.Cardinality.UNARY_UNARY,
                featureflags_protobuf.service_pb2.StoreStatsTask,
                google.protobuf.empty_pb2.Empty,
            ),
            '/featureflags_protobuf.service.FeatureFlags/StoreStats': grpclib.const.Handler(
                self.StoreStats,
                grpclib.const.Cardinality.UNARY_UNARY,
                featureflags_protobuf.service_pb2.StoreStatsTask,
                google.protobuf.empty_pb2.Empty,
            ),
        }


class FeatureFlagsStub:

    def __init__(self, channel: grpclib.client.Channel) -> None:
        self.exchange = grpclib.client.UnaryUnaryMethod(
            channel,
            '/featureflags_protobuf.service.FeatureFlags/exchange',
            featureflags_protobuf.service_pb2.ExchangeRequest,
            featureflags_protobuf.service_pb2.ExchangeReply,
        )
        self.Exchange = grpclib.client.UnaryUnaryMethod(
            channel,
            '/featureflags_protobuf.service.FeatureFlags/Exchange',
            featureflags_protobuf.service_pb2.ExchangeRequest,
            featureflags_protobuf.service_pb2.ExchangeReply,
        )
        self.store_stats = grpclib.client.UnaryUnaryMethod(
            channel,
            '/featureflags_protobuf.service.FeatureFlags/store_stats',
            featureflags_protobuf.service_pb2.StoreStatsTask,
            google.protobuf.empty_pb2.Empty,
        )
        self.StoreStats = grpclib.client.UnaryUnaryMethod(
            channel,
            '/featureflags_protobuf.service.FeatureFlags/StoreStats',
            featureflags_protobuf.service_pb2.StoreStatsTask,
            google.protobuf.empty_pb2.Empty,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags_protobuf/service.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags_protobuf import graph_pb2 as featureflags__protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#featureflags_protobuf/service.proto\x12\x1d\x66\x65\x61tureflags_protobuf.service\x1a\x19hiku/protobuf/query.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags_protobuf/graph.proto\"R\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.featureflags_protobuf.graph.Variable.Type\"w\n\tFlagUsage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r\"\xd8\x01\n\x0f\x45xchangeRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12:\n\tvariables\x18\x03 \x03(\x0b\x32\'.featureflags_protobuf.service.Variable\x12=\n\x0b\x66lags_usage\x18\x04 \x03(\x0b\x32(.featureflags_protobuf.service.FlagUsage\x12(\n\x05query\x18\x05 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"U\n\rExchangeReply\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x33\n\x06result\x18\x02 \x01(\x0b\x32#.featureflags_protobuf.graph.Result\"\x7f\n\x0eStoreStatsTask\x12\x0f\n\x07\x66lag_id\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r2\x9b\x03\n\x0c\x46\x65\x61tureFlags\x12m\n\x08\x65xchange\x12..featureflags_protobuf.service.ExchangeRequest\x1a,.featureflags_protobuf.service.ExchangeReply\"\x03\x88\x02\x01\x12j\n\x08\x45xchange\x12..featureflags_protobuf.service.ExchangeRequest\x1a,.featureflags_protobuf.service.ExchangeReply\"\x00\x12Y\n\x0bstore_stats\x12-.featureflags_protobuf.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12U\n\nStoreStats\x12-.featureflags_protobuf.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureflags_protobuf.service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FEATUREFLAGS'].methods_by_name['exchange']._options = None
  _globals['_FEATUREFLAGS'].methods_by_name['exchange']._serialized_options = b'\210\002\001'
  _globals['_FEATUREFLAGS'].methods_by_name['store_stats']._options = None
  _globals['_FEATUREFLAGS'].methods_by_name['store_stats']._serialized_options = b'\210\002\001'
  _globals['_VARIABLE']._serialized_start=194
  _globals['_VARIABLE']._serialized_end=276
  _globals['_FLAGUSAGE']._serialized_start=278
  _globals['_FLAGUSAGE']._serialized_end=397
  _globals['_EXCHANGEREQUEST']._serialized_start=400
  _globals['_EXCHANGEREQUEST']._serialized_end=616
  _globals['_EXCHANGEREPLY']._serialized_start=618
  _globals['_EXCHANGEREPLY']._serialized_end=703
  _globals['_STORESTATSTASK']._serialized_start=705
  _globals['_STORESTATSTASK']._serialized_end=832
  _globals['_FEATUREFLAGS']._serialized_start=835
  _globals['_FEATUREFLAGS']._serialized_end=1246
# @@protoc_insertion_point(module_scope)
